pub struct RenderResult {
    pub content: String,
    pub has_collapsible_table: bool,
    pub metadata: Option<Yaml>,
    pub fenced_code_contents: HashMap<usize, String>,
}

Fields

content: Stringhas_collapsible_table: bool

This flag tells you if the document has a collapsible table.

metadata: Option<Yaml>fenced_code_contents: HashMap<usize, String>

Some fenced codes have a copy button with them. Each button has an index of the fenced code. This hashmap maps the index and the content of the fenced code. Use this data when writing javascript for the copy buttons.